@@ -18,10 +18,11 @@ from dkist_processing_test.tasks.quality import TestQualityL0Metrics
 from dkist_processing_test.tasks.write_l1 import WriteL1Data
 
 end_to_end = Workflow(
-    process_category="test",
-    process_name="management_processes_end_to_end",
+    input_data="input",
+    output_data="output",
+    category="test",
+    detail="management-processes-e2e",
     workflow_package=__package__,
-    tags=["test"],
 )
 end_to_end.add_node(task=TransferL0Data, upstreams=None)
 end_to_end.add_node(task=ParseL0TestInputData, upstreams=TransferL0Data)
